import { WebDavProtocol } from "@/models/WebDavProtocol.js";
import { WebDavProtocolItem } from "@/models/WebDavProtocolItem.js";
import { AllOs, AllBrowsers } from "@/settings/webDavProtocol.js";
import { ITHit } from "webdav.client";

export default {
  /**
   * Gets Protocol
   * @returns {WebDavProtocol}
   */
  getProtocol() {
    var webDavProtocol = null;
    let currentBrowserProtocol = this.getCurrentBrowserProtocol();
    let currentOsProtocol = this.getCurrentOsProtocol();
    webDavProtocol = new WebDavProtocol(
      currentOsProtocol,
      currentBrowserProtocol,
      currentOsProtocol
        ? AllOs.filter(c => c.CssClass != currentOsProtocol.CssClass)
        : AllOs,
      currentBrowserProtocol
        ? AllBrowsers.filter(c => c.CssClass != currentBrowserProtocol.CssClass)
        : AllBrowsers
    );
    return webDavProtocol;
  },
  /**
   * Gets current browser Protocol item
   * @returns {WebDavProtocolItem}
   */
  getCurrentBrowserProtocol() {
    var isChrome =
      !!window["chrome"] &&
      (!!window["chrome"]["webstore"] || !!window["chrome"]["runtime"]);
    var currentBrowserProtocol = null;
    if (isChrome && navigator.userAgent.indexOf("Edg") !== -1) {
      currentBrowserProtocol = AllBrowsers.filter(
        c => c.CssClass == "edge-chromium"
      ).shift();
    } else if (isChrome) {
      currentBrowserProtocol = AllBrowsers.filter(
        c => c.CssClass == "goole-chrome"
      ).shift();
    } else if (typeof InstallTrigger !== "undefined") {
      currentBrowserProtocol = AllBrowsers.filter(
        c => c.CssClass == "mozilla-firefox"
      ).shift();
    } else if (
      navigator.userAgent.indexOf("MSIE ") > 0 ||
      !!navigator.userAgent.match(/Trident.*rv\\:11\./)
    ) {
      currentBrowserProtocol = new WebDavProtocolItem(
        "The extension is not required for Internet Explorer.",
        "",
        "",
        "not-required-internet-explorer"
      );
    }
    return currentBrowserProtocol;
  },
  /**
   * Gets current OS Protocol item
   * @returns {WebDavProtocolItem}
   */
  getCurrentOsProtocol() {
    var currentOsProtocol = null;
    if (ITHit.DetectOS.OS === "Windows") {
      currentOsProtocol = AllOs.filter(c => c.CssClass == "window").shift();
    } else if (ITHit.DetectOS.OS === "Linux") {
      currentOsProtocol = AllOs.filter(c => c.CssClass == "linux").shift();
    } else if (ITHit.DetectOS.OS === "MacOS") {
      currentOsProtocol = AllOs.filter(c => c.CssClass == "mac-os").shift();
    }
    return currentOsProtocol;
  },
  /**
   * Is dav protocol supported
   * @returns {Boolean}
   */
  isDavProtocolSupported() {
    return ITHit.WebDAV.Client.DocManager.IsDavProtocolSupported();
  },
  /**
   * Is microsoft office document
   * @returns {Boolean}
   */
  isMicrosoftOfficeDocument(sHref) {
    return ITHit.WebDAV.Client.DocManager.IsMicrosoftOfficeDocument(sHref);
  }
};
